@@ -11,7 +11,6 @@ from skimage import data, morphology, util
 
 
 class Skeletonize3d:
-
     def setup(self, *args):
         try:
             # use a separate skeletonize_3d function on older scikit-image
@@ -51,8 +50,8 @@ class Skeletonize3d:
 # For binary morphology all functions ultimately are based on a single erosion
 # function in the scipy.ndimage C code, so only benchmark binary_erosion here.
 
-class BinaryMorphology2D:
 
+class BinaryMorphology2D:
     # skip rectangle as roughly equivalent to square
     param_names = ["shape", "footprint", "radius", "decomposition"]
     params = [
@@ -101,19 +100,15 @@ class BinaryMorphology2D:
         elif footprint == "ellipse":
             if radius > 1:
                 # make somewhat elliptical
-                self.footprint = fp_func(radius - 1, radius + 1,
-                                         **footprint_kwargs)
+                self.footprint = fp_func(radius - 1, radius + 1, **footprint_kwargs)
             else:
                 self.footprint = fp_func(radius, radius, **footprint_kwargs)
 
-    def time_erosion(
-        self, shape, footprint, radius, *args
-    ):
+    def time_erosion(self, shape, footprint, radius, *args):
         morphology.binary_erosion(self.image, self.footprint)
 
 
 class BinaryMorphology3D:
-
     # skip rectangle as roughly equivalent to square
     param_names = ["shape", "footprint", "radius", "decomposition"]
     params = [
@@ -145,14 +140,11 @@ class BinaryMorphology3D:
         elif footprint in ["ball", "octahedron"]:
             self.footprint = fp_func(radius, **footprint_kwargs)
 
-    def time_erosion(
-        self, shape, footprint, radius, *args
-    ):
+    def time_erosion(self, shape, footprint, radius, *args):
         morphology.binary_erosion(self.image, self.footprint)
 
 
 class IsotropicMorphology2D:
-
     # skip rectangle as roughly equivalent to square
     param_names = ["shape", "radius"]
     params = [
@@ -166,33 +158,25 @@ class IsotropicMorphology2D:
         # (so it will not become fully False for any of the footprints).
         self.image = rng.standard_normal(shape) < 3.5
 
-    def time_erosion(
-        self, shape, radius, *args
-    ):
+    def time_erosion(self, shape, radius, *args):
         morphology.isotropic_erosion(self.image, radius)
 
 
 # Repeat the same footprint tests for grayscale morphology
 # just need to call morphology.erosion instead of morphology.binary_erosion
 
-class GrayMorphology2D(BinaryMorphology2D):
 
-    def time_erosion(
-        self, shape, footprint, radius, *args
-    ):
+class GrayMorphology2D(BinaryMorphology2D):
+    def time_erosion(self, shape, footprint, radius, *args):
         morphology.erosion(self.image, self.footprint)
 
 
 class GrayMorphology3D(BinaryMorphology3D):
-
-    def time_erosion(
-        self, shape, footprint, radius, *args
-    ):
+    def time_erosion(self, shape, footprint, radius, *args):
         morphology.erosion(self.image, self.footprint)
 
 
 class GrayReconstruction:
-
     # skip rectangle as roughly equivalent to square
     param_names = ["shape", "dtype"]
     params = [
@@ -243,7 +227,6 @@ class GrayReconstruction:
 
 
 class LocalMaxima:
-
     param_names = ["connectivity", "allow_borders"]
     params = [(1, 2), (False, True)]
 
@@ -253,8 +236,7 @@ class LocalMaxima:
 
     def time_2d(self, connectivity, allow_borders):
         morphology.local_maxima(
-            self.image, connectivity=connectivity,
-            allow_borders=allow_borders
+            self.image, connectivity=connectivity, allow_borders=allow_borders
         )
 
     def peakmem_reference(self, *args):
@@ -264,8 +246,7 @@ class LocalMaxima:
         """
         pass
 
-    def peakmem_2d(self,connectivity, allow_borders):
+    def peakmem_2d(self, connectivity, allow_borders):
         morphology.local_maxima(
-            self.image, connectivity=connectivity,
-            allow_borders=allow_borders
+            self.image, connectivity=connectivity, allow_borders=allow_borders
         )
