@@ -1,5 +1,5 @@
 """
-Attempt to generate templates for module reference with Sphinx
+Attempt to generate templates for module reference with Sphinx.
 
 To include extension modules, first identify them as valid in the
 ``_uri2path`` method, then handle them in the ``_parse_module_with_import``
@@ -28,44 +28,42 @@ DEBUG = True
 
 
 class ApiDocWriter:
-    ''' Class for automatic detection and parsing of API docs
-    to Sphinx-parsable reST format'''
+    """Automatic detection and parsing of API docs to Sphinx-parsable reST format."""
 
     # only separating first two levels
     rst_section_levels = ['*', '=', '-', '~', '^']
 
-    def __init__(self,
-                 package_name,
-                 rst_extension='.rst',
-                 package_skip_patterns=None,
-                 module_skip_patterns=None,
-                 ):
-        r''' Initialize package for parsing
+    def __init__(
+        self,
+        package_name,
+        rst_extension='.rst',
+        package_skip_patterns=None,
+        module_skip_patterns=None,
+    ):
+        r"""Initialize package for parsing
 
         Parameters
         ----------
         package_name : string
-            Name of the top-level package.  *package_name* must be the
-            name of an importable package
+            Name of the top-level package. *package_name* must be the
+            name of an importable package.
         rst_extension : string, optional
-            Extension for reST files, default '.rst'
+            Extension for reST files, default '.rst'.
         package_skip_patterns : None or sequence of {strings, regexps}
             Sequence of strings giving URIs of packages to be excluded
             Operates on the package path, starting at (including) the
             first dot in the package path, after *package_name* - so,
             if *package_name* is ``sphinx``, then ``sphinx.util`` will
-            result in ``.util`` being passed for earching by these
-            regexps.  If is None, gives default. Default is:
-            ['\.tests$']
+            result in ``.util`` being passed for searching by these
+            regexps.  If is None, gives default. Default is ``['\.tests$']``.
         module_skip_patterns : None or sequence
             Sequence of strings giving URIs of modules to be excluded
             Operates on the module name including preceding URI path,
             back to the first dot after *package_name*.  For example
             ``sphinx.util.console`` results in the string to search of
-            ``.util.console``
-            If is None, gives default. Default is:
-            ['\.setup$', '\._']
-        '''
+            ``.util.console``.
+            If is None, gives default. Default is ``['\.setup$', '\._']``.
+        """
         if package_skip_patterns is None:
             package_skip_patterns = ['\\.tests$']
         if module_skip_patterns is None:
@@ -79,7 +77,7 @@ class ApiDocWriter:
         return self._package_name
 
     def set_package_name(self, package_name):
-        ''' Set package_name
+        """Set package_name
 
         >>> docwriter = ApiDocWriter('sphinx')
         >>> import sphinx
@@ -89,18 +87,19 @@ class ApiDocWriter:
         >>> import docutils
         >>> docwriter.root_path == docutils.__path__[0]
         True
-        '''
+        """
         # It's also possible to imagine caching the module parsing here
         self._package_name = package_name
         root_module = self._import(package_name)
         self.root_path = root_module.__path__[-1]
         self.written_modules = None
 
-    package_name = property(get_package_name, set_package_name, None,
-                            'get/set package_name')
+    package_name = property(
+        get_package_name, set_package_name, None, 'get/set package_name'
+    )
 
     def _import(self, name):
-        ''' Import namespace package '''
+        """Import namespace package."""
         mod = __import__(name)
         components = name.split('.')
         for comp in components[1:]:
@@ -108,7 +107,8 @@ class ApiDocWriter:
         return mod
 
     def _get_object_name(self, line):
-        ''' Get second token in line
+        """Get second token in line.
+
         >>> docwriter = ApiDocWriter('sphinx')
         >>> docwriter._get_object_name("  def func():  ")
         'func'
@@ -116,14 +116,14 @@ class ApiDocWriter:
         'Klass'
         >>> docwriter._get_object_name("  class Klass:  ")
         'Klass'
-        '''
+        """
         name = line.split()[1].split('(')[0].strip()
         # in case we have classes which are not derived from object
         # ie. old style classes
         return name.rstrip(':')
 
     def _uri2path(self, uri):
-        ''' Convert uri to absolute filepath
+        """Convert uri to absolute filepath.
 
         Parameters
         ----------
@@ -149,14 +149,14 @@ class ApiDocWriter:
         True
         >>> docwriter._uri2path('sphinx.does_not_exist')
 
-        '''
+        """
         if uri == self.package_name:
             return os.path.join(self.root_path, '__init__.py')
         path = uri.replace(self.package_name + '.', '')
         path = path.replace('.', os.path.sep)
         path = os.path.join(self.root_path, path)
         # XXX maybe check for extensions as well?
-        if os.path.exists(path + '.py'): # file
+        if os.path.exists(path + '.py'):  # file
             path += '.py'
         elif os.path.exists(os.path.join(path, '__init__.py')):
             path = os.path.join(path, '__init__.py')
@@ -165,7 +165,7 @@ class ApiDocWriter:
         return path
 
     def _path2uri(self, dirpath):
-        ''' Convert directory path to uri '''
+        """Convert directory path to uri."""
         package_dir = self.package_name.replace('.', os.path.sep)
         relpath = dirpath.replace(self.root_path, package_dir)
         if relpath.startswith(os.path.sep):
@@ -173,19 +173,19 @@ class ApiDocWriter:
         return relpath.replace(os.path.sep, '.')
 
     def _parse_module(self, uri):
-        ''' Parse module defined in *uri* '''
+        """Parse module defined in uri."""
         filename = self._uri2path(uri)
         if filename is None:
             print(filename, 'erk')
             # nothing that we could handle here.
-            return ([],[])
+            return ([], [])
         with open(filename) as f:
             functions, classes = self._parse_lines(f)
 
         return functions, classes
 
     def _parse_module_with_import(self, uri):
-        """Look for functions and classes in an importable module.
+        """Look for functions and classes in the importable module.
 
         Parameters
         ----------
@@ -204,8 +204,9 @@ class ApiDocWriter:
         """
         mod = __import__(uri, fromlist=[uri.split('.')[-1]])
         # find all public objects in the module.
-        obj_strs = getattr(mod, '__all__',
-                           [obj for obj in dir(mod) if not obj.startswith('_')])
+        obj_strs = getattr(
+            mod, '__all__', [obj for obj in dir(mod) if not obj.startswith('_')]
+        )
         functions = []
         classes = []
         submodules = []
@@ -217,7 +218,7 @@ class ApiDocWriter:
                 continue
 
             # figure out if obj is a function or class
-            if isinstance(obj, (FunctionType, BuiltinFunctionType)):
+            if isinstance(obj, FunctionType | BuiltinFunctionType):
                 functions.append(obj_str)
             elif isinstance(obj, ModuleType) and 'skimage' in mod.__name__:
                 submodules.append(obj_str)
@@ -231,7 +232,7 @@ class ApiDocWriter:
         return functions, classes, submodules
 
     def _parse_lines(self, linesource):
-        ''' Parse lines of text for functions and classes '''
+        """Parse lines of text for functions and classes."""
         functions = []
         classes = []
         for line in linesource:
@@ -252,18 +253,18 @@ class ApiDocWriter:
         return functions, classes
 
     def generate_api_doc(self, uri):
-        '''Make autodoc documentation template string for a module
+        """Make autodoc documentation template string for a module.
 
         Parameters
         ----------
         uri : string
-            python location of module - e.g 'sphinx.builder'
+            Python location of module - e.g 'sphinx.builder'.
 
         Returns
         -------
         S : string
-            Contents of API doc
-        '''
+            Contents of API doc.
+        """
         # get the names of all classes and functions
         functions, classes, submodules = self._parse_module_with_import(uri)
         if not (len(functions) or len(classes) or len(submodules)) and DEBUG:
@@ -290,7 +291,7 @@ class ApiDocWriter:
             ad += '   ' + uri + '.' + c + '\n'
         ad += '\n'
         for m in submodules:
-            ad += '    ' + uri + '.' + m + '\n'
+            ad += '   ' + uri + '.' + m + '\n'
         ad += '\n'
 
         for f in functions:
@@ -302,20 +303,22 @@ class ApiDocWriter:
         for c in classes:
             ad += '\n.. autoclass:: ' + c + '\n'
             # must NOT exclude from index to keep cross-refs working
-            ad += '  :members:\n' \
-                  '  :inherited-members:\n' \
-                  '  :undoc-members:\n' \
-                  '  :show-inheritance:\n' \
-                  '\n' \
-                  '  .. automethod:: __init__\n\n'
+            ad += (
+                '  :members:\n'
+                '  :inherited-members:\n'
+                '  :undoc-members:\n'
+                '  :show-inheritance:\n'
+                '\n'
+                '  .. automethod:: __init__\n\n'
+            )
             full_c = uri + '.' + c
             ad += f'    .. minigallery:: {full_c}\n\n'
         return ad
 
     def _survives_exclude(self, matchstr, match_type):
-        ''' Returns True if *matchstr* does not match patterns
+        """Return True if matchstr does not match patterns.
 
-        ``self.package_name`` removed from front of string if present
+        Removes ``self.package_name`` from the beginning of the string if present.
 
         Examples
         --------
@@ -332,7 +335,7 @@ class ApiDocWriter:
         >>> dw.module_skip_patterns.append('^\\.badmod$')
         >>> dw._survives_exclude('sphinx.badmod', 'module')
         False
-        '''
+        """
         if match_type == 'module':
             patterns = self.module_skip_patterns
         elif match_type == 'package':
@@ -353,17 +356,12 @@ class ApiDocWriter:
         return True
 
     def discover_modules(self):
-        r''' Return module sequence discovered from ``self.package_name``
-
-
-        Parameters
-        ----------
-        None
+        r"""Return module sequence discovered from ``self.package_name``.
 
         Returns
         -------
         mods : sequence
-            Sequence of module names within ``self.package_name``
+            Sequence of module names within ``self.package_name``.
 
         Examples
         --------
@@ -375,17 +373,17 @@ class ApiDocWriter:
         >>> 'sphinx.util' in dw.discover_modules()
         False
         >>>
-        '''
+        """
         modules = [self.package_name]
         # raw directory parsing
         for dirpath, dirnames, filenames in os.walk(self.root_path):
             # Check directory names for packages
-            root_uri = self._path2uri(os.path.join(self.root_path,
-                                                   dirpath))
-            for dirname in dirnames[:]: # copy list - we modify inplace
+            root_uri = self._path2uri(os.path.join(self.root_path, dirpath))
+            for dirname in dirnames[:]:  # copy list - we modify inplace
                 package_uri = '.'.join((root_uri, dirname))
-                if (self._uri2path(package_uri) and
-                    self._survives_exclude(package_uri, 'package')):
+                if self._uri2path(package_uri) and self._survives_exclude(
+                    package_uri, 'package'
+                ):
                     modules.append(package_uri)
                 else:
                     dirnames.remove(dirname)
@@ -394,15 +392,13 @@ class ApiDocWriter:
     def write_modules_api(self, modules, outdir):
         # write the list
         written_modules = []
-        public_modules = [m for m in modules
-                          if not m.split('.')[-1].startswith('_')]
+        public_modules = [m for m in modules if not m.split('.')[-1].startswith('_')]
         for m in public_modules:
             api_str = self.generate_api_doc(m)
             if not api_str:
                 continue
             # write out to file
-            outfile = os.path.join(outdir,
-                                   m + self.rst_extension)
+            outfile = os.path.join(outdir, m + self.rst_extension)
             with open(outfile, 'w') as fileobj:
                 fileobj.write(api_str)
             written_modules.append(m)
@@ -414,16 +410,12 @@ class ApiDocWriter:
         Parameters
         ----------
         outdir : string
-            Directory name in which to store files
-            We create automatic filenames for each module
-
-        Returns
-        -------
-        None
+            Directory name in which to store the files. Filenames for each module
+            are automatically created.
 
         Notes
         -----
-        Sets self.written_modules to list of written modules
+        Sets self.written_modules to list of written modules.
         """
         if not os.path.exists(outdir):
             os.mkdir(outdir)
@@ -432,25 +424,25 @@ class ApiDocWriter:
         self.write_modules_api(modules, outdir)
 
     def write_index(self, outdir, froot='gen', relative_to=None):
-        """Make a reST API index file from written files
+        """Make a reST API index file from the written files.
 
         Parameters
         ----------
         outdir : string
-            Directory to which to write generated index file
+            Directory to which to write generated index file.
         froot : string, optional
-            root (filename without extension) of filename to write to
-            Defaults to 'gen'.  We add ``self.rst_extension``.
+            Root (filename without extension) of filename to write to
+            Defaults to 'gen'. We add ``self.rst_extension``.
         relative_to : string
-            path to which written filenames are relative.  This
+            Path to which written filenames are relative. This
             component of the written file path will be removed from
-            outdir, in the generated index.  Default is None, meaning,
+            outdir, in the generated index. Default is None, meaning,
             leave path as it is.
         """
         if self.written_modules is None:
             raise ValueError('No modules written')
         # Get full filename path
-        path = os.path.join(outdir, froot+self.rst_extension)
+        path = os.path.join(outdir, froot + self.rst_extension)
         # Path written into index is relative to rootpath
         if relative_to is not None:
             relpath = (outdir + os.path.sep).replace(relative_to + os.path.sep, '')
